@@ -38,14 +38,14 @@ import gobject
 # Cell_info - Taken from netmon code. Need to figure out the author so i can give proper thanks!
 # can be found here - http://repository.maemo.org/extras-devel/pool/fremantle/free/source/n/netmon/
 import gn_cellinfo
-#import gtk
+import gtk
 
 # osso_c = osso.Context("healthcheck", "666", True)
 
 #Threading imports!
-# from threading import Thread
-# import time
-# gtk.gdk.threads_init()
+from threading import Thread
+import time
+gtk.gdk.threads_init()
 
 
 
@@ -302,7 +302,7 @@ class Ui_MainWindow(object):
         # box of some sort
         self.textBrowser = QtGui.QTextBrowser(self.tab_2)
         self.textBrowser.setGeometry(QtCore.QRect(0, 10, 781, 301))
-        self.textBrowser.setText ("Health Check V 0.4.2 \n Greg Roberts (Maemo.org - Noobmonkey) \n me@greg-roberts.com")
+        self.textBrowser.setText (" Health Check V 0.4.2-9 \n Greg Roberts (Maemo.org - Noobmonkey) \n me@greg-roberts.com")
         # Make the font small!!!
         font = QtGui.QFont()
         font.setPointSize(20)
@@ -445,28 +445,29 @@ class Ui_MainWindow(object):
         
         self.pushButton_hw.setEnabled(False)
         self.pushButton_hw.setText(".")
-        self.updaterootfs()
+        
+        Thread(target=self.updaterootfs()).start()
         self.pushButton_hw.setText("..")
-        self.updateAccel()
+        Thread(target=self.updateAccel()).start()
         self.pushButton_hw.setText("...")
-        self.updateCPU()
+        Thread(target=self.updateCPU()).start()
         self.pushButton_hw.setText("....")
-        self.updateGPS()
+        Thread(target=self.updateGPS()).start()
         self.pushButton_hw.setText(".....")
-        self.updateMaemoV()
+        Thread(target=self.updateMaemoV()).start()
         self.pushButton_hw.setText("......")
-        self.updateImage()
+        Thread(target=self.updateImage()).start()
         self.pushButton_hw.setText(".......")
-        self.updateBatt()
+        Thread(target=self.updateBatt()).start()
         self.pushButton_hw.setText("........")
-        #self.Cellular()
+        Thread(target=self.Cellular()).start()
         self.pushButton_hw.setText("Update")
         self.pushButton_hw.setEnabled(True)
 
         
     # This is the start of the QT Designer translation function - not using the translation function, but left it in, to show it is part of the class   
     def retranslateUi(self, MainWindow):
-        MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", "Health Check 0.4.1", None, QtGui.QApplication.UnicodeUTF8))
+        MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", "Health Check 0.4.2-9", None, QtGui.QApplication.UnicodeUTF8))
         self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab), QtGui.QApplication.translate("MainWindow", "System Information", None, QtGui.QApplication.UnicodeUTF8))
         self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_2), QtGui.QApplication.translate("MainWindow", "About", None, QtGui.QApplication.UnicodeUTF8))
 
